/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2003 - 2004 by NetCat Inc., www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/

import java.awt.*;

import li.netcat.print.*;
import li.netcat.print.table.*;
import li.netcat.print.util.*;

public class DecoratorExample {
  
  public static void main(String[] args)	{
    new PrintPreview(createPrint()).open();
  }

  public static Print createPrint() {
    GridPrint grid = new GridPrint(10, 10);
    grid.add(createBackgroundPrint());
    grid.add(createBackgroundPrint2());
    grid.add(createInsetsPrint());
    grid.add(createBorderPrint());
    grid.add(createDecoratedTable());
    grid.add(createDecoratedTable2());
    return grid;
  }
  
  public static Print createBackgroundPrint() {
    return new BackgroundPrint(new TextPrint("This TextPrint is decorated by a BackgroundPrint."), Color.yellow);
  }
  
  public static Print createBackgroundPrint2() {
    return new BackgroundPrint(TableLineBreakExample.createPrint(), Color.yellow);
  }
  
  public static Print createInsetsPrint() {
    // define insets top:10,left:30,bottom:10,right:30
    Insets insets = new Insets(10, 30, 10, 30);
    // decorate print of example TableLineBreakExample with insets 
    Print print = new InsetsPrint(TableLineBreakExample.createPrint(), insets);
    // make insets visible with a background print
    return new BackgroundPrint(print, Color.yellow);
  }
  
  public static Print createBorderPrint() {
    Print print = new TextPrint("This TextPrint is decorated by a BorderPrint that uses a LinePrintBorder.");
    // define the border
    LinePrintBorder border = new LinePrintBorder();
    // define insets top:10,left:30,bottom:10,right:30
    border.setInsets(new Insets(10, 30, 10, 30));
    // decorate print with border 
    return new BorderPrint(print, border);
  }
  
  public static Print createDecoratedTable() {
    // note that we can decorate any print, it must not be a table
    Print print = TableLineBreakExample.createPrint();
    // define a border that uses a drawer before and after a page break
    // the default constructor paints ">>" before and after the break
    DrawerPrintBorder border = new DrawerPrintBorder();
    // decorate print with border 
    return new BorderPrint(print, border);
  }
  
  public static Print createDecoratedTable2() {
    // lets use the table of the TableLineBreakExample
    TablePrint table = TableLineBreakExample.createTable();
    // set my own look to the table.
    //table.setLook(new HtmlTableLook());
    // define my own HtmlTableBorder that dashse the top and bottom line.
    // the default constructor paints ">>" before and after the break
    HtmlTableBorder border = new HtmlTableBorder();
    // decorate the table with the border
    Print print = new BorderPrint(table, border);
    // that's fun! lets decorate the decorated table with a brawer border
    DrawerPrintBorder border2 = new DrawerPrintBorder();
    // decorate print with border 
    return new BorderPrint(print, border2);
  }
  
  
}
